@@ -53,6 +53,7 @@
 #define HAVE_MALLOC_H 1
 #define HAVE_PWD_H 1
 #define HAVE_SANITIZER_ASAN_INTERFACE_H 1
+#define HAVE_SANITIZER_MSAN_INTERFACE_H 1
 #define HAVE_STDALIGN_H 1
 #define HAVE_STDIO_H 1
 #define HAVE_SYS_EVENTFD_H 1
@@ -177,8 +178,7 @@
 #define HAVE_FUNC_WEAK 1
 #define RUBY_CXX_DEPRECATED(msg) __attribute__((__deprecated__(msg)))
 #define HAVE_NULLPTR 1
-#define FUNC_UNOPTIMIZED(x) __attribute__ ((__optimize__("O0"))) x
-#define FUNC_MINIMIZED(x) __attribute__ ((__optimize__("-Os","-fomit-frame-pointer"))) x
+#define FUNC_CDECL(x) __attribute__ ((__cdecl__)) x
 #define HAVE_ATTRIBUTE_FUNCTION_ALIAS 1
 #define RUBY_ALIAS_FUNCTION_TYPE(type, prot, name, args) type prot __attribute__((alias(#name)));
 #define RUBY_ALIAS_FUNCTION_VOID(prot, name, args) RUBY_ALIAS_FUNCTION_TYPE(void, prot, name, args)
@@ -432,7 +432,6 @@
 #define HAVE_BUILTIN___BUILTIN_ADD_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_SUB_OVERFLOW 1
 #define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW 1
-#define HAVE_BUILTIN___BUILTIN_MUL_OVERFLOW_P 1
 #define HAVE_BUILTIN___BUILTIN_CONSTANT_P 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR 1
 #define HAVE_BUILTIN___BUILTIN_CHOOSE_EXPR_CONSTANT_P 1
